Learn R Programming

openholidaysR (version 0.1.0)

openholidaysR-package: openholidaysR: Provides Access to the 'OpenHolidays' API

Description

Provides dates for public and school holidays for a number of countries and their subdivisions through the 'OpenHolidays' API at https://www.openholidaysapi.org/en/.

Arguments

Author

Maintainer: Johannes Feldhege mail@johannesfeldhege.de (ORCID) [copyright holder]

See Also