Learn R Programming

openholidaysR (version 0.1.0)

oh_public_holidays: Get public holidays for a given country and time period

Description

Get public holidays for a given country and time period

Usage

oh_public_holidays(country, language = "EN", start_date, end_date)

Value

A data frame of holidays for a given country and time period.

Arguments

country

Country ISO code (e.g. "DE" for Germany).

language

Language ISO code (default: "EN").

start_date

Start date of time period (YYYY-MM-DD).

end_date

End date of time period (YYYY-MM-DD).

Examples

Run this code
if (FALSE) { # identical(Sys.getenv("IN_PKGDOWN"), "true")
# Get all holidays for Germany for the year 2025

oh_public_holidays(country = "DE",
                   language = "EN",
                   start_date = "2025-01-01",
                   end_date = "2025-12-31")
}

Run the code above in your browser using DataLab