Learn R Programming

openholidaysR (version 0.1.0)

oh_public_holidays_by_date: Get public holidays for a specific date for all countries

Description

Get public holidays for a specific date for all countries

Usage

oh_public_holidays_by_date(date, language = "EN")

Value

A data frame of holidays for all countries.

Arguments

date

date (YYYY-MM-DD).

language

Language ISO code (default: "EN").

Examples

Run this code
if (FALSE) { # identical(Sys.getenv("IN_PKGDOWN"), "true")
oh_public_holidays_by_date(date = "2025-12-25")
}

Run the code above in your browser using DataLab