powered by
Get school holidays for a specific date for all countries
oh_school_holidays_by_date(date, language = "EN")
A data frame of school holidays for all countries.
date (YYYY-MM-DD).
Language ISO code (default: "EN").
if (FALSE) { # identical(Sys.getenv("IN_PKGDOWN"), "true") oh_school_holidays_by_date(date = "2025-01-06") }
Run the code above in your browser using DataLab