openholidaysR-package: openholidaysR: Provides Access to the 'OpenHolidays' API
Description
Provides dates for public and school holidays for a number of countries and their subdivisions through the 'OpenHolidays' API at https://www.openholidaysapi.org/en/.